==> haskell-memory-0.17.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-memory.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 memory
version:              0.17.0
visibility:           public
id:                   memory-0.17.0-Ba80JGdi30PBt5EgUiQ1Tu
key:                  memory-0.17.0-Ba80JGdi30PBt5EgUiQ1Tu
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:
    vincent@snarc.org, Nicolas Di Prima <nicolas@primetype.co.uk>

author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-memory
synopsis:             memory and related abstraction stuff
description:
    Chunk of memory, polymorphic byte array management and manipulation

    * A polymorphic byte array abstraction and function similar to strict ByteString.

    * Different type of byte array abstraction.

    * Raw memory IO operations (memory set, memory copy, ..)

    * Aliasing with endianness support.

    * Encoding : Base16, Base32, Base64.

    * Hashing : FNV, SipHash

category:             memory
abi:                  bfc1732b44ef6a06d6ef999577f7b424
exposed:              True
exposed-modules:
    Data.ByteArray Data.ByteArray.Encoding Data.ByteArray.Hash
    Data.ByteArray.Mapping Data.ByteArray.Pack Data.ByteArray.Parse
    Data.ByteArray.Sized Data.Memory.Encoding.Base16
    Data.Memory.Encoding.Base32 Data.Memory.Encoding.Base64
    Data.Memory.Endian Data.Memory.ExtendedWords Data.Memory.PtrMethods

hidden-modules:
    Data.Memory.Internal.Compat Data.Memory.Internal.CompatPrim
    Data.Memory.Internal.CompatPrim64 Data.Memory.Internal.DeepSeq
    Data.Memory.Internal.Imports Data.Memory.Hash.SipHash
    Data.Memory.Hash.FNV Data.ByteArray.Pack.Internal
    Data.ByteArray.Types Data.ByteArray.Bytes
    Data.ByteArray.ScrubbedBytes Data.ByteArray.Methods
    Data.ByteArray.MemView Data.ByteArray.View Data.Memory.MemMap.Posix

import-dirs:          /usr/lib/ghc-9.0.2/site-local/memory-0.17.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/memory-0.17.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memory
hs-libraries:         HSmemory-0.17.0-Ba80JGdi30PBt5EgUiQ1Tu
depends:
    base-4.15.1.0 basement-0.0.16-Klm23hGhb6c6Td2Q8VURcD
    bytestring-0.10.12.1 deepseq-1.4.5.0 ghc-prim-0.7.0

haddock-interfaces:   /usr/share/doc/haskell-memory/html/memory.haddock
haddock-html:         /usr/share/doc/haskell-memory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memory-0.18.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-memory.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 memory
version:              0.18.0
visibility:           public
id:                   memory-0.18.0-KC0M2DcF55TEVHxP6av2cL
key:                  memory-0.18.0-KC0M2DcF55TEVHxP6av2cL
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:
    vincent@snarc.org, Nicolas Di Prima <nicolas@primetype.co.uk>

author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-memory
synopsis:             memory and related abstraction stuff
description:
    Chunk of memory, polymorphic byte array management and manipulation

    * A polymorphic byte array abstraction and function similar to strict ByteString.

    * Different type of byte array abstraction.

    * Raw memory IO operations (memory set, memory copy, ..)

    * Aliasing with endianness support.

    * Encoding : Base16, Base32, Base64.

    * Hashing : FNV, SipHash

category:             memory
abi:                  42caa33cf9f9376abb9ad60c4f406627
exposed:              True
exposed-modules:
    Data.ByteArray Data.ByteArray.Encoding Data.ByteArray.Hash
    Data.ByteArray.Mapping Data.ByteArray.Pack Data.ByteArray.Parse
    Data.ByteArray.Sized Data.Memory.Encoding.Base16
    Data.Memory.Encoding.Base32 Data.Memory.Encoding.Base64
    Data.Memory.Endian Data.Memory.ExtendedWords Data.Memory.PtrMethods

hidden-modules:
    Data.Memory.Internal.Compat Data.Memory.Internal.CompatPrim
    Data.Memory.Internal.CompatPrim64 Data.Memory.Internal.DeepSeq
    Data.Memory.Internal.Imports Data.Memory.Hash.SipHash
    Data.Memory.Hash.FNV Data.ByteArray.Pack.Internal
    Data.ByteArray.Types Data.ByteArray.Bytes
    Data.ByteArray.ScrubbedBytes Data.ByteArray.Methods
    Data.ByteArray.MemView Data.ByteArray.View Data.Memory.MemMap.Posix

import-dirs:          /usr/lib/ghc-9.0.2/site-local/memory-0.18.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/memory-0.18.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memory
hs-libraries:         HSmemory-0.18.0-KC0M2DcF55TEVHxP6av2cL
depends:
    base-4.15.1.0 basement-0.0.16-Klm23hGhb6c6Td2Q8VURcD
    bytestring-0.10.12.1 deepseq-1.4.5.0 ghc-prim-0.7.0

haddock-interfaces:   /usr/share/doc/haskell-memory/html/memory.haddock
haddock-html:         /usr/share/doc/haskell-memory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
